@@ -5,7 +5,7 @@ use time::{OffsetDateTime, UtcOffset};
 
 /// Period kind.
 #[derive(Debug, Clone, Copy)]
-enum PeriodKind {
+pub enum PeriodKind {
     /// A year.
     Year,
     /// A month.
@@ -263,6 +263,11 @@ impl Period {
     pub fn utc_offset(&self) -> UtcOffset {
         self.offset
     }
+
+    /// Get period kind.
+    pub fn kind(&self) -> PeriodKind {
+        self.kind
+    }
 }
 
 const WEEK_OFFSET: Duration = Duration::from_secs(4 * DAY_SECS);
